#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit
set -o pipefail

# NOTE (fdegir): we need to remove $WORKSPACE and clone infra/engine repository
# as infra/engine is what drives the deployment
if [[ "$GERRIT_PROJECT" != "infra/engine" ]]; then
  cd "$HOME" && /bin/rm -rf "$WORKSPACE"
  echo "Info : Cloning infra/engine repository"
  git clone -q https://gerrit.nordix.org/infra/engine.git "$WORKSPACE"
  cd "$WORKSPACE"
fi

if [[ "$EXECUTION_MODE" == "offline-deployment" ]]; then
  ENGINE_ROOT_DIR="/opt/engine/offline/git/engine"
else
  ENGINE_ROOT_DIR="$WORKSPACE"
fi

# TODO (fdegir): this is temporarily here to develop the jobs
if [[ "$GERRIT_PROJECT" != "infra/engine" ]]; then
  cd $ENGINE_ROOT_DIR
  git fetch "https://gerrit.nordix.org/infra/engine" refs/changes/23/4823/18 && git checkout FETCH_HEAD
fi

# NOTE (fdegir): for bifrost based deployments, we don't need these files so we fake them
OPENRC_FILE=${OPENRC_FILE:-/tmp/openrc}
HEAT_ENVIRONMENT_FILENAME=${HEAT_ENVIRONMENT_FILENAME:-/tmp/heat}

/bin/cp -f $OPENRC_FILE /tmp/openrc

cd "$ENGINE_ROOT_DIR/engine"
./deploy.sh -d -s "$STACK_TYPE" -v "$STACK_VERSION" -p "$PDF" -i "$IDF" -o /tmp/openrc

# vim: set ts=2 sw=2 expandtab:
